# BIFROST
## Reduction Workflows

::::{grid} 3

:::{grid-item-card} BIFROST Reduction
:link: bifrost-reduction.ipynb
:text-align: center

```{image} ../../_static/thumbnails/bifrost_reduction_light.svg
:class: only-light
:width: 100%
```
```{image} ../../_static/thumbnails/bifrost_reduction_dark.svg
:class: only-dark
:width: 100%
```
:::

::::

```{toctree}
---
hidden:
---

bifrost-reduction
bifrost-bragg-peak-monitor
```

## Advanced Tools

```{toctree}
---
maxdepth: 1
---

bifrost-make-wavelength-lookup-table
```
